@@ -11,9 +11,11 @@ __all__ = [
     "journal",
     "store",
     "timeline",
+    "timespan",
     "timezone",
     "todo",
     "types",
     "tzif",
     "util",
+    "diagnostics",
 ]
